@@ -356,7 +356,7 @@ def main():
             print 'Current Version {}'.format(__version__)
             print '\nChecking for updates...'
             update = client.update_check('Not So TUF', __version__)
-            if update:
+            if update and not client.up_to_date:
                 print 'About to install update and restart'
                 client.install_restart()
         try:
