@@ -46,6 +46,7 @@ class Client(object):
         self.version_url = self.update_url + self.version_file
         self.json_data = None
         self.verified = False
+        self.up_to_date = False
         if self.data_dir is None:
             extra = '.'
             if sys.platform == 'win32':
@@ -174,6 +175,7 @@ start {} "{}" """.format(updated_app, current_app, fix, current_app))
             return False
         if _version_string_to_tuple(highest_version) <= _version_string_to_tuple(version):
             log.info('{} already updated to the latest version'.format(name))
+            self.up_to_date = True
             return True
 
         # Just checking to see if the latest update is available to patch
@@ -213,7 +215,8 @@ start {} "{}" """.format(updated_app, current_app, fix, current_app))
         highest_version = self._get_highest_version(name)
         if _version_string_to_tuple(highest_version) <= _version_string_to_tuple(version):
             log.info('{} already updated to the latest version'.format(name))
-            return
+            self.up_to_date = True
+            return True
 
         url = self._get_file_url(name, highest_version)
         filename = self._get_filename_with_extension(name,
